defmodule OpWeb.QueriLive.Index do
  use OpWeb, :live_view

  alias Op.Base
  alias Op.Base.Queri

  @impl true
  def mount(_params, _session, socket) do
    {:ok, stream(socket, :queries, Base.list_queries())}
  end

  @impl true
  def handle_params(params, _url, socket) do
    {:noreply, apply_action(socket, socket.assigns.live_action, params)}
  end

  defp apply_action(socket, :edit, %{"id" => id}) do
    socket
    |> assign(:page_title, "Edit Queri")
    |> assign(:queri, Base.get_queri!(id))
  end

  defp apply_action(socket, :new, _params) do
    socket
    |> assign(:page_title, "New Queri")
    |> assign(:queri, %Queri{})
  end

  defp apply_action(socket, :index, _params) do
    socket
    |> assign(:page_title, "Listing Queries")
    |> assign(:queri, nil)
  end

  @impl true
  def handle_info({OpWeb.QueriLive.FormComponent, {:saved, queri}}, socket) do
    {:noreply, stream_insert(socket, :queries, queri)}
  end

  @impl true
  def handle_event("delete", %{"id" => id}, socket) do
    queri = Base.get_queri!(id)
    {:ok, _} = Base.delete_queri(queri)

    {:noreply, stream_delete(socket, :queries, queri)}
  end
end
